@@ -1,9 +1,13 @@
 mod core;
+pub mod description;
 mod endpoint;
 mod filter;
 mod filter_map;
+mod map;
 
 pub use self::core::*;
+pub use description::HandlerDescription;
 pub use endpoint::*;
 pub use filter::*;
 pub use filter_map::*;
+pub use map::*;
